@@ -47,11 +47,64 @@ class Dari:
     # ------------------------------------------------------------------
     # Workflow execution helpers
     # ------------------------------------------------------------------
-    def start_workflow(self, workflow_id: str, input_variables: Mapping[str, Any]) -> Dict[str, Any]:
-        """Trigger a workflow execution with the provided input variables."""
+    def start_workflow(
+        self,
+        workflow_id: str,
+        input_variables: Mapping[str, Any],
+        *,
+        timeout_minutes: Optional[int] = None,
+        should_update_cache: Optional[bool] = None,
+        allow_public_live_view: Optional[bool] = None,
+        browser_profile_id: Optional[str] = None,
+        use_proxy: Optional[bool] = None,
+        proxy_city: Optional[str] = None,
+        proxy_server: Optional[str] = None,
+        proxy_server_username: Optional[str] = None,
+        proxy_server_password: Optional[str] = None,
+        user_agent: Optional[str] = None,
+    ) -> Dict[str, Any]:
+        """Trigger a workflow execution with the provided input variables.
 
-        payload = {"input_variables": dict(input_variables)}
-        return self._request("POST", f"/workflows/start/{workflow_id}", json=payload)
+        Args:
+            workflow_id: The unique identifier of the workflow to start
+            input_variables: Key-value pairs of input variable names and their values
+            timeout_minutes: Maximum execution time in minutes
+            should_update_cache: Whether to update the execution cache (default: True)
+            allow_public_live_view: Enable public live viewing of the workflow execution (default: False)
+            browser_profile_id: UUID of a browser profile to use for this workflow execution
+            use_proxy: Enable proxy for browser sessions in this workflow
+            proxy_city: Proxy location (New York, Los Angeles, Chicago, Seattle, Miami, Toronto, London, Frankfurt, Singapore, Sydney)
+            proxy_server: Custom proxy server URL (e.g., http://proxy.example.com:8080)
+            proxy_server_username: Username for custom proxy server authentication
+            proxy_server_password: Password for custom proxy server authentication
+            user_agent: Custom user agent string for browser sessions
+
+        Returns:
+            Dict containing workflow_execution_id and status
+        """
+
+        payload: Dict[str, Any] = {"input_variables": dict(input_variables)}
+        if timeout_minutes is not None:
+            payload["timeout_minutes"] = timeout_minutes
+        if should_update_cache is not None:
+            payload["should_update_cache"] = should_update_cache
+        if allow_public_live_view is not None:
+            payload["allow_public_live_view"] = allow_public_live_view
+        if browser_profile_id is not None:
+            payload["browser_profile_id"] = browser_profile_id
+        if use_proxy is not None:
+            payload["use_proxy"] = use_proxy
+        if proxy_city is not None:
+            payload["proxy_city"] = proxy_city
+        if proxy_server is not None:
+            payload["proxy_server"] = proxy_server
+        if proxy_server_username is not None:
+            payload["proxy_server_username"] = proxy_server_username
+        if proxy_server_password is not None:
+            payload["proxy_server_password"] = proxy_server_password
+        if user_agent is not None:
+            payload["user_agent"] = user_agent
+        return self._request("POST", f"/public/workflows/start/{workflow_id}", json=payload)
 
     def list_workflow_executions(self, workflow_id: str) -> Dict[str, Any]:
         """Return executions for the given workflow."""
@@ -75,7 +128,7 @@ class Dari:
     def list_credentials(self) -> Any:
         """Return saved browser credentials."""
 
-        return self._request("GET", "/credentials")
+        return self._request("GET", "/public/credentials")
 
     def create_credential(
         self,
@@ -100,23 +153,53 @@ class Dari:
             payload["gmail_oauth_account_id"] = gmail_oauth_account_id
         if phone_number_id is not None:
             payload["phone_number_id"] = phone_number_id
-        return self._request("POST", "/credentials", json=payload)
+        return self._request("POST", "/public/credentials", json=payload)
 
     def list_connected_accounts(self) -> Any:
         """Return OAuth accounts associated with the workspace."""
 
-        return self._request("GET", "/connected-accounts")
+        return self._request("GET", "/public/connected-accounts")
 
     def list_phone_numbers(self) -> Any:
         """Return all phone numbers for the workspace."""
 
-        return self._request("GET", "/phone-numbers")
+        return self._request("GET", "/public/phone-numbers")
 
     def purchase_phone_number(self, *, label: str) -> Dict[str, Any]:
         """Purchase a new Twilio phone number for the workspace."""
 
         payload = {"label": label}
-        return self._request("POST", "/phone-numbers", json=payload)
+        return self._request("POST", "/public/phone-numbers", json=payload)
+
+    def create_browser_profile(
+        self,
+        *,
+        name: str,
+        provider: Optional[str] = None,
+    ) -> Dict[str, Any]:
+        """Create a new browser profile to persist cookies, login sessions, and browser state.
+
+        Args:
+            name: A unique name for the browser profile
+            provider: Browser provider to use (hyperbrowser or kernel), defaults to hyperbrowser
+
+        Returns:
+            Dict containing id, name, and created_at
+        """
+
+        payload: Dict[str, Any] = {"name": name}
+        if provider is not None:
+            payload["provider"] = provider
+        return self._request("POST", "/public/browser-profiles", json=payload)
+
+    def list_browser_profiles(self) -> Dict[str, Any]:
+        """Return all browser profiles in the workspace.
+
+        Returns:
+            Dict containing profiles array with id, name, and created_at for each profile
+        """
+
+        return self._request("GET", "/public/browser-profiles")
 
     # ------------------------------------------------------------------
     # Computer use helpers
@@ -158,7 +241,7 @@ class Dari:
             payload["screen_config"] = dict(screen_config)
         if set_cache is not None:
             payload["set_cache"] = set_cache
-        return self._request("POST", "/single-actions/run-action", json=payload, timeout=120)
+        return self._request("POST", "/public/single-actions/run-action", json=payload, timeout=120)
 
     # ------------------------------------------------------------------
     # Browser session management
@@ -192,7 +275,7 @@ class Dari:
             payload["ttl"] = ttl
         if metadata is not None:
             payload["metadata"] = dict(metadata)
-        return self._request("POST", "/sessions", json=payload)
+        return self._request("POST", "/public/sessions", json=payload)
 
     def get_session(self, session_id: str) -> Dict[str, Any]:
         """Get details of a specific session.
@@ -204,7 +287,7 @@ class Dari:
             Dict containing session details
         """
 
-        return self._request("GET", f"/sessions/{session_id}")
+        return self._request("GET", f"/public/sessions/{session_id}")
 
     def list_sessions(
         self,
@@ -231,7 +314,7 @@ class Dari:
             params["limit"] = limit
         if offset is not None:
             params["offset"] = offset
-        return self._request("GET", "/sessions", params=params if params else None)
+        return self._request("GET", "/public/sessions", params=params if params else None)
 
     def update_session(
         self,
@@ -256,7 +339,7 @@ class Dari:
             payload["ttl"] = ttl
         if metadata is not None:
             payload["metadata"] = dict(metadata)
-        return self._request("PATCH", f"/sessions/{session_id}", json=payload)
+        return self._request("PATCH", f"/public/sessions/{session_id}", json=payload)
 
     def terminate_session(self, session_id: str) -> None:
         """Terminate a session.
@@ -265,7 +348,7 @@ class Dari:
             session_id: The session ID to terminate
         """
 
-        self._request("POST", f"/sessions/{session_id}/terminate")
+        self._request("POST", f"/public/sessions/{session_id}/terminate")
 
     def delete_session(self, session_id: str) -> None:
         """Delete a session.
@@ -274,7 +357,7 @@ class Dari:
             session_id: The session ID to delete
         """
 
-        self._request("DELETE", f"/sessions/{session_id}")
+        self._request("DELETE", f"/public/sessions/{session_id}")
 
     # ------------------------------------------------------------------
     # Session helpers
